@@ -60,12 +60,18 @@ sub instance_load {
 	error("$db_package failed: $@$advice\n");
     }
     my($instance);
-    eval "\$instance = $db_package->new()";
-    error("$@") if(!defined($instance));
+    eval { $instance = $db_package->new() };
+    error("$@") unless $instance;
 
     $self->{'instance'} = $instance;
 }
 
+sub connect_error_handler {
+    my($self, $func) = @_;
+
+    $self->{'instance'}->{'connect_error_handler'} = $func;
+}
+
 sub instance { shift->{'instance'}; }
 
 sub quote { shift->instance()->quote(@_); }
